@@ -290,4 +290,16 @@ impl LuaShared {
 		crate::open_library_raw!("bin/linux64/lua_shared.so")
 		.expect("Failed to find lua_shared.so")
 	}
+
+	#[cfg(all(target_os = "macos", target_pointer_width = "32"))]
+	pub unsafe fn find_lua_shared() -> (Library, &'static str) {
+		crate::open_library_raw!("garrysmod/bin/lua_shared.dylib")
+		.expect("Failed to find lua_shared.dylib")
+	}
+
+	#[cfg(all(target_os = "macos", target_pointer_width = "64"))]
+	pub unsafe fn find_lua_shared() -> (Library, &'static str) {
+		crate::open_library_raw!("GarrysMod_Signed.app/Contents/MacOS/lua_shared.dylib")
+		.expect("Failed to find lua_shared.dylib")
+	}
 }
